#
# spec file for package picom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           picom
Version:        12.5
Release:        1.2
Summary:        Stand-alone compositor for X11
License:        MIT AND MPL-2.0
Group:          System/X11/Utilities
URL:            https://github.com/yshui/picom
Source:         https://github.com/yshui/picom/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
%if 0%{?suse_version} > 1500
BuildRequires:  c_compiler
%else
# on Leap 15.x, gcc7 is the default compiler and it results in many compiling errors, thus force use of gcc12
BuildRequires:  gcc12
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  uthash-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libconfig) >= 1.7
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libxdg-basedir)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-damage)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-present)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-sync)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xext)
BuildRequires:  rubygem(asciidoctor)
Recommends:     rtkit
Obsoletes:      compton <= 0.1.0
Provides:       compton = %{version}

%description
Picom is a stand-alone compositor for X11. It supports both GLX and
XRender backends and has various options to control shadows, blur
and fade animations.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} <= 1500
export CC=gcc-12
%endif
%meson -Dwith_docs=true -Dcompton=false -Dvsync_drm=true
%meson_build

%install
%meson_install
install -d %{buildroot}%{_datadir}/icons/hicolor/{48x48,scalable}/apps
install -m644 media/icons/48x48/compton.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -m644 media/compton.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
# don't need this
rm %{buildroot}%{_libdir}/pkgconfig/%{name}-api.pc
# Fix boo#1222766
rm %{buildroot}%{_sysconfdir}/xdg/autostart/%{name}.desktop

%check
%meson --reconfigure -Dunittest=true
%meson_test

%files
%license LICENSES/MPL-2.0 LICENSES/MIT COPYING
%doc CONTRIBUTORS README.md picom.sample.conf
%{_bindir}/%{name}*
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-trans.1%{?ext_man}
%{_mandir}/man1/%{name}-inspect.1%{?ext_man}

%changelog
* Fri Nov 15 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to version 12.5:
  * Bug fixes
  - Fix assertion failure when running with some window managers (e.g. qtile) and no window is focused (#1384)
- Update to version 12.4:
  * Improvements
  - Better workaround for a NVIDIA quirk, fix high CPU usage when
    screen is off (#1265)
  - Avoid using xrender convolution in all cases, should improve
    shadow performance for most users (#1349)
  * Bug fixes
  - Fix leak of saved window images
  * Build fixes
  - Fix build on arm32 (#1355)
* Tue Oct 15 2024 Michael Pujos <pujos.michael@gmail.com>
- removed picom-11.2-rtkit.patch now upstreamed
- Update to version 12.3:
  * Improvements
  - Extend workaround for missing hardware accelerated convolution to more drivers (#1349)
  * Bug fixes
  - Fix memory corruption that can happen when handling window property changes (#1350)
  - Fix force-win-blend having no effect (#1354)
  - Fix shadow being rendered incorrectly in xrender backend (#1352)
- Update to version 12.2:
  * Improvements
  - fly-out/slide-out animation presets no longer cause jumps in window opacity
  * Bug fixes
  - Random delays before screen is updated (#1345 #1330)
  - Fix building on 32-bit systems (#1346)
  - Fix blank screen on 32-bit systems
  - Fix fly-in/fly-out animation presets so they work with directions
    other than up and left
- Update to version 12.1:
  * Bug fixes
  - picom stops rendering correctly after monitor configuration changes (#1338)
- Update to version 12:
  * New features
  - Animations! Yes, now picom officially supports animations.
    For examples, and information on how to configure it, please go to our documentation site
    There are some video clips in #1253 as well. (#1220 #1253 #1303 #1305 #1308 #1310)
  - Universal window rules (#1284). One option to rule them all!
    Added new configuration option rules to replace all existing rule options,
    and to provide more flexibility on top of that. See picom(1) for more details.
    This can be used to configure per-window animations
  - @include directives in config file now also search in $XDG_CONFIG_HOME/picom/include
    and $XDG_CONFIG_DIRS/picom/include, in addition to relative to the config file's
    parent directory
  - Allow corner-radius-rules to override corner-radius = 0.
    Previously setting corner radius to 0 globally disables rounded corners. (#1170)
  - New picom-inspect tool, which lets you test out your picom rules.
    man picom-inspect(1) for more details
  - picom now has a rudimentary plugin system.
    At the moment, the only thing you can do with it is loading custom backends
  * Notable changes
  - override_redirect in rules now only matches top-level windows that doesn't have
    a client window. Some window managers (e.g. awesome) set override_redirect for
    all window manager frame windows, causing this rule to match against everything (#625)
  - Marginally improve performance when resizing/opening/closing windows. (#1190)
  - Type and format specifiers are no longer used in rules. These specifiers are what
    you put after the colon (':') in rules, e.g. the :32c in "_GTK_FRAME_EXTENTS@:32c".
    Now this information is ignored and the property is matched regardless of format or type
  - backend is now a required option. picom will not start if one is not specified explicitly
  - New predefined target for conditions: group_focused. This target indicate whether the
    focused window is in the same window group as the window being matched
  - Meaning of window_type in conditions changed slightly, now it supports windows with
    multiple types. (However the behavior of wintypes remains unchanged)
  * Deprecated features
  - Setting --shadow-exclude-reg is now a hard error. It was deprecated almost since
    the start of picom. --clip-shadow-above is the better alternative. (#1254)
  - Remove command line options -n, -a, and -s. They were removed more than 10 years ago,
    it's time to finally get rid of them entirely. (#1254)
  - Remove error message for --glx-swap-method, it was deprecated in v6
  - Remove error message for passing argument to --vsync arguments, it was deprecated in v5
  - Option --opengl is now deprecated, use --backend=glx instead
  * Bug fixes
  - Fix ghosting artifacts that sometimes occur when window manager is restarted (#1081)
  - Fix a bug where rounded corner is disabled after making a window fullscreen and back (#1216)
  - Fix ugly looking rounded corners (#1261)
  - Setting corner-radius to 0 cause all windows to not render (#1311)
  - Setting corner-radius causes windows to have a 1-pixel transparent border
  - Window shaders no longer work (#1312)
  * Build changes
  - picom now uses some OpenGL 4.3 features
  - picom now optionally depends on rtkit at runtime to give itself realtime scheduling priority
  - libconfig is now a mandatory dependency, with a minimal supported version of 1.7
  - xcb-dpms is not needed anymore
  - libXext is not needed anymore
  - man pages are now built with asciidoctor, instead of asciidoc
* Tue Apr 16 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Add picom-11.2-rtkit.patch: Support setting realtime priority
  using rtkit (commits 7bbf316a7d54334c97ae2055238db7b772562ec5,
  23d4d31d1f477591d7830712a1e53764e875955f,
  615924cc4af317cc3062cef6cf4c784bca7d77c0,
  dc3271e81bce422b4e43123a465fc8634b8fdaf4).
* Mon Apr 15 2024 Giacomo Comes <gcomes.obs@gmail.com>
- do not install /etc/xdg/autostart/picom.desktop
  * fix boo#1222766
* Tue Feb 13 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 11.2:
  * picom now depends on libepoxy for OpenGL symbol management.
  * Workaround a NVIDIA problem that causes high CPU usage after
    suspend/resume.
  * Fix occasional freezes.
  * Fix corner-radius-rules not applying sometimes.
  * Fix window shader not having an effect when frame opacity is
    enabled.
  * Fix binding root pixmap in case of depth mismatch
    (boo#1217786).
- Remove picom-11.1-fix-nvidia-high-cpu-usage.patch: fixed
  upstream.
* Sat Feb  3 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 11.1 (changes since 10.2):
  * Notable features
  - picom now uses dithering to prevent banding. Banding is most
    notable when using a strong background blur.
  - Frame pacing. picom uses present feedback information to
    schedule new frames when it makes sense to do so. This
    improves latency, and replaces the `glFlush` and
    `GL_MaxFramesAllowed=1` hacks we used to do for NVIDIA.
  - Some missing features have been implemented for the EGL
    backend.
  * Bug fixes
  - Many memory/resource leak fixes.
  - Fix tiling of wallpaper.
  - Fix some blur artefacts.
  - Fix shadow colour for transparent shadows.
  - Don't spam logs when another compositor is running.
  - Fix rounded corners showing as black with the xrender
    backend.
  - Fix blur with rounded windows.
  - Fix missing fading on window close for some window managers.
  * Build changes
  - Dependency `pcre` has been replaced by `pcre2`.
  - New dependency xcb-util.
  - xinerama is no longer used.
  - picom now tries to give itself a real-time scheduling
    priority.
  * Deprecations
  - The `kawase` blur method is removed. Note this is just an
    alias to the `dual_kawase` method, which is still available.
  - Uses of `--sw-opti`, and `--respect-prop-shadow` are now hard
    errors.
  - `-F` has been removed completely. It was deprecated in 2012.
- Drop patches included in upstream:
  * 0001-core-expand-X-error-handling.patch
  * 0002-core-added-proper-event-handling-for-XESetWireToEven.patch
  * 0003-core-event-code-refactoring.patch
- Add picom-11.1-fix-nvidia-high-cpu-usage.patch: Workaround a
  NVIDIA problem that causes high CPU usage after suspend/resume
  (adapted from commit 238c3cc8336fe24370a3ca44ff0d891ca8907c94).
* Tue Oct 17 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Add patch to Picom spamming Xlib: ignoring invalid extension event 161 errors.
  gh#yshui/picom#1096
  Backport patch from next branch
  0001-core-expand-X-error-handling.patch
  0002-core-added-proper-event-handling-for-XESetWireToEven.patch
  0003-core-event-code-refactoring.patch
* Wed Dec 21 2022 Mia Herkt <mia@0x0.st>
- Update to version 10.2
  Fixes:
  * Window border not being considered when calculating its mask
    gh#yshui/picom#950
* Wed Nov 23 2022 Mia Herkt <mia@0x0.st>
- Update to version 10.1
  Fixes:
  * A GL texture leak, related to
    gh#yshui/picom#892
  * A crash when shadow radius is set to 0
    gh#yshui/picom#927
  * An undefined symbol error
    gh#yshui/picom#932
* Mon Nov 14 2022 Mia Herkt <mia@0x0.st>
- Update to version 10
  * picom now needs libEGL to build
  Notable changes:
  * experimental-backends is now the default. Everything should
    keep working, except the --glx-fshader-win option. The old
    window shader support has been replaced by --window-shader-fd.
    This new shader support has a different interface, so you have
    to adapt your existing shaders.
    gh#yshui/picom#875
  * legacy-backends option has been added so you can go back to the
    old backends, which will eventually be removed.
  * picom.desktop is installed to /etc/xdg/autostart/.
    picom should autostart now.
    gh#yshui/picom#791
  * Shadows and blur now match the shape of the window.
    This includes windows using the XShape extension, and windows
    with rounded corners.
    gh#yshui/picom#882
  * New option: --transparent-clipping-exclude, for excluding
    windows that doesn't play well with transparent-clipping,
    such as screenshot tool windows.
    gh#yshui/picom#663
    gh#yshui/picom#738
  * New backend: egl. It should behave exactly the same as the glx
    backend. Give it a try!
    gh#yshui/picom#878
  Other changes:
  * --help messages have been refactored, leading to clearer code.
    gh#yshui/picom#877
  * picom tries to detect and act on GPU resets. But because of the
    limitation of the X server, this ended up not being very
    useful.
* Sat May 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 9.1:
  * Bug Fixes:
    [#770] #778
  * No further changelog
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 8.2:
  * Fixes assertion failures related to WIN_FLAGS_SHADOW_STALE, see #479
  * write-pid-path in configuration file now accepted, see #492
  * Pid files are now deleted during shutdown, see #492
  * Build fixes for certain platforms, see #501, #502
* Sun Jun 14 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Since it requires dbus, use dbus by default.
* Sat May  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Updated to version 8
  * You can now use the time variable in window shaders to get a
    timestamp. An example usage is to create animated effects,
    e.g. https://streamable.com/e0x7r
  * --max-brightness, which allows you to dim windows that are
    too bright. When enabled, all windows' average brightness will
    be clamped to the set value.
  * Automatic configuration file reloading after it's changed.
  * A lot of the artifacts seen with blur and use-damage enabled
    are fixed.
  * _NET_WM_BYPASS_COMPOSITOR property are now handled.
    (Related to i3/i3lock#204)
  * Completely transparent windows won't have a blurred background
    anymore.
  * Improved fullscreen window detection. Now EWMH is used to
    detect fullscreen windows as well. You can turn it off with
  - -no-ewmh-fullscreen
  * Various improvments to the inverter.sh script
  * wintype notify has been renamed to notification to match the
    EWMH names. (Old name still works)
  * picom no longer sets the opacity property on windows based on
    opacity rules. This is to fix the problem where picom "forgets"
    it set the opacity property after, e.g., window manager
    restarts.
  * libxdg-basedir is no longer a dependency
  * Fixed wrong client window detection after i3wm restarts
  * Fixed wallpaper disappearing after screen resolution changes.
  * Fixed crashing when a really big window is created with shadow
  * Fixed --frame-opacity with the experimental backends
  * --blur-* command line options are now handled properly
  * Various build fixes
  * Various memory leakage fixes
  * Various documentation fixes and improvments
  * Various other crash, assertion failure fixes
  * Fixed some left over problems related to terminals in floating
    scratchpads losing transparency after restarting i3
  * Using these options is now an error: alpha-step, -d, -S,
  - -no-named-pixmap xrender-sync. They were deprecated in v5.
    paint-on-overlay, --dbe. They were deprecated in v4.
  * Error messages will no longer be printed for these removed
    options: glx-use-copysubbuffermesa, glx-copy-from-front.
    They were removed in v7
* Mon Nov 18 2019 9+suse@cirno.systems
- init, 7.4+159.g9a88d97
